@@ -30,18 +30,10 @@ pub mod camera;
 pub use self::camera::Camera;
 pub mod camera_request;
 pub use self::camera_request::CameraRequest;
-pub mod camera_source_type_enum;
-pub use self::camera_source_type_enum::CameraSourceTypeEnum;
 pub mod camera_type_enum;
 pub use self::camera_type_enum::CameraTypeEnum;
 pub mod command_enum;
 pub use self::command_enum::CommandEnum;
-pub mod create_ansible_facts_request;
-pub use self::create_ansible_facts_request::CreateAnsibleFactsRequest;
-pub mod create_appliance_pki_request;
-pub use self::create_appliance_pki_request::CreateAppliancePkiRequest;
-pub mod create_appliance_request;
-pub use self::create_appliance_request::CreateApplianceRequest;
 pub mod detail_response;
 pub use self::detail_response::DetailResponse;
 pub mod device_calibration;
@@ -62,6 +54,8 @@ pub mod experiment_device_config;
 pub use self::experiment_device_config::ExperimentDeviceConfig;
 pub mod gcode_file;
 pub use self::gcode_file::GcodeFile;
+pub mod inline_response_403;
+pub use self::inline_response_403::InlineResponse403;
 pub mod mobile_auth_request;
 pub use self::mobile_auth_request::MobileAuthRequest;
 pub mod model_artifact;
